import * as ts from "typescript";
import { IConversionResult, IConverter } from "../../converter";
import { IFileSystem } from "../../files";
import { IRunOptions } from "../../runner";
/**
 * Dependencies to initialize a new instance of the TypeScriptConverter class.
 */
export interface ITypeScriptConverterDependencies {
    /**
     * Options for the TypeScript compiler.
     */
    compilerOptions: ts.CompilerOptions;
    /**
     * Reads and writes files.
     */
    fileSystem: IFileSystem;
}
/**
 * Extension for TypeScript files.
 */
export declare const tsExtension = ".ts";
/**
 * Converts TypeScript files to their GLS outputs.
 */
export declare class TypeScriptConverter implements IConverter {
    /**
     * Dependencies used for initialization.
     */
    private readonly dependencies;
    /**
     * TypeScript source files, keyed by unique file path.
     */
    private readonly sourceFiles;
    /**
     * Transforms TypeScript to GLS.
     */
    private readonly transformer;
    /**
     * Initializes a new instance of the TypeScriptConverter class.
     *
     * @param dependencies   Dependencies used for initialization.
     * @param options   Options for converting files.
     */
    constructor(dependencies: ITypeScriptConverterDependencies, options: IRunOptions);
    /**
     * Converts a TypeScript file to its GLS output.
     *
     * @param filePath   Original GLS file path.
     * @returns The file's GLS output.
     */
    convertFile(filePath: string): Promise<IConversionResult>;
}
