"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var chalk_1 = require("chalk");
var os_1 = require("os");
var converter_1 = require("./converter");
var asyncQueue_1 = require("./utils/asyncQueue");
var text_1 = require("./utils/text");
/**
 * Persistent runner for converting files.
 */
var Runner = /** @class */ (function () {
    /**
     * Initializes a new instance of the Runner class.
     *
     * @param dependencies   Dependencies to be used for initialization.
     */
    function Runner(dependencies) {
        var _this = this;
        /**
         * Converts a file.
         *
         * @param filePath   Path to the file.
         * @param options   Options for converting files.
         * @returns A Promise for converting the file.
         */
        this.runOnFile = function (filePath, options) { return __awaiter(_this, void 0, void 0, function () {
            var result;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.dependencies.logger.log(chalk_1.default.grey("Converting"), "" + filePath + chalk_1.default.grey("..."));
                        return [4 /*yield*/, this.dependencies.coordinator.convertFile(filePath, options)];
                    case 1:
                        result = _a.sent();
                        if (result.status === converter_1.ConversionStatus.Failed) {
                            this.dependencies.logger.error(chalk_1.default.grey.italic("Failed converting"), [
                                chalk_1.default.red.bold(filePath),
                                chalk_1.default.grey.italic(":"),
                                os_1.EOL,
                                text_1.indent(chalk_1.default.italic.red(result.error.stack === undefined ? result.error.message : result.error.stack)),
                            ].join(""));
                        }
                        else {
                            this.dependencies.logger.log(chalk_1.default.italic("Converted"), chalk_1.default.bold(filePath), chalk_1.default.italic("to"), chalk_1.default.bold.green(result.outputPath));
                        }
                        return [2 /*return*/, result];
                }
            });
        }); };
        this.dependencies = dependencies;
    }
    /**
     * Converts a set of files.
     *
     * @param options   Options for converting files.
     * @returns A Promise for converting the files.
     */
    Runner.prototype.run = function (options) {
        return __awaiter(this, void 0, void 0, function () {
            var fileResults;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        fileResults = {};
                        return [4 /*yield*/, asyncQueue_1.queueAsyncActions(Array.from(options.files)
                                .map(function (_a) {
                                var fileName = _a[0];
                                return function () { return __awaiter(_this, void 0, void 0, function () {
                                    return __generator(this, function (_a) {
                                        switch (_a.label) {
                                            case 0: return [4 /*yield*/, this.runOnFile(fileName, options)
                                                    .then(function (result) {
                                                    fileResults[fileName] = result;
                                                })];
                                            case 1:
                                                _a.sent();
                                                return [2 /*return*/];
                                        }
                                    });
                                }); };
                            }))];
                    case 1:
                        _a.sent();
                        this.dependencies.logger.log(chalk_1.default.italic("Ran on"), chalk_1.default.bold("" + options.files.size), chalk_1.default.italic("file" + (options.files.size === 1 ? "" : "s") + "."));
                        return [2 /*return*/, { fileResults: fileResults }];
                }
            });
        });
    };
    return Runner;
}());
exports.Runner = Runner;
//# sourceMappingURL=runner.js.map